==> qcad-3.15.5.3.tgz: lib/qcad/scripts/File/Save/ts/Save_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+77"/>
        <source>Overwrite File?</source>
        <translation>Prepišem datoteko?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Datoteka &apos;%1&apos; že obstaja. Jo želite prepisat?</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>File Format Version Not Recommended</source>
        <translation>Verzija datotečnega formata ni priporočena</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>Verzija datotečnega formata, ki ga uporabljate ni priporočena: &apos;%1&apos; .</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Vse črne entitete in plasti bodo shranjeni kot beli.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Vse prilagojene barve bodo &apos;zaokrožene&apos; na najbližjo fiksno barvo.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Proceed?</source>
        <translation>Nadaljujem?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saving...</source>
        <translation>Shranjujem...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Shranjevanje v datotečni format verzije &apos;%1&apos; .</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Črne entitete in plasti so shranjene kot bele.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Prilagojene barve so &apos;zaokrožene&apos; na najbližjo fiksno barvo.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Datoteka &apos;%1&apos;, ni bila shranjena.</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saved drawing:</source>
        <translation>Shranjena risba:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Shrani</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/File/Save/ts/Save_sl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sl_SI">
<context>
    <name>Save</name>
    <message>
        <location filename="../Save.js" line="+78"/>
        <source>Overwrite File?</source>
        <translation>Prepišem datoteko?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Datoteka &apos;%1&apos; že obstaja. Jo želite prepisat?</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>File Format Version Not Recommended</source>
        <translation>Verzija datotečnega formata ni priporočena</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file format version you are using is not recommended: &apos;%1&apos;.</source>
        <translation>Verzija datotečnega formata, ki ga uporabljate ni priporočena: &apos;%1&apos; .</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom properties will not be saved.</source>
        <translation>Prilagojene lastnosti ne bodo shranjene.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All black entities and layers will be saved as white.</source>
        <translation>Vse črne entitete in plasti bodo shranjeni kot beli.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>All custom colors will be &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Vse prilagojene barve bodo &apos;zaokrožene&apos; na najbližjo fiksno barvo.</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Proceed?</source>
        <translation>Nadaljujem?</translation>
    </message>
    <message>
        <location line="+16"/>
        <source>Saving...</source>
        <translation>Shranjujem...</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Saving to file format version &apos;%1&apos;.</source>
        <translation>Shranjevanje v datotečni format verzije &apos;%1&apos; .</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Black entities and layers are saved as white.</source>
        <translation>Črne entitete in plasti so shranjene kot bele.</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Custom colors are &apos;rounded&apos; to the nearest fixed color.</source>
        <translation>Prilagojene barve so &apos;zaokrožene&apos; na najbližjo fiksno barvo.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>File %1 has not been saved.</source>
        <translation>Datoteka &apos;%1&apos;, ni bila shranjena.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Saved drawing:</source>
        <translation>Shranjena risba:</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <location filename="../SaveInit.js" line="+2"/>
        <source>&amp;Save</source>
        <translation>&amp;Shrani</translation>
    </message>
</context>
</TS>
